@@ -3,7 +3,7 @@ package Locale::TextDomain::OO::Util;
 use strict;
 use warnings;
 
-our $VERSION = '3.001';
+our $VERSION = '3.003';
 
 1;
 
@@ -12,13 +12,13 @@ __END__
 =head1 NAME
 Locale::TextDomain::OO::Util - Lexicon utils
 
-$Id: Util.pm 539 2014-10-27 10:18:37Z steffenw $
+$Id: Util.pm 592 2015-06-28 05:22:48Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/Locale-TextDomain-OO-Util/trunk/lib/Locale/TextDomain/OO/Util.pm $
 
 =head1 VERSION
 
-3.001
+3.003
 
 =head1 DESCRIPTION
 
@@ -73,7 +73,7 @@ none
 
 =head1 SEE ALSO
 
-L<Locale::TextDoamin::OO|Locale::TextDoamin::OO>
+L<Locale::TextDomain::OO|Locale::TextDomain::OO>
 
 =head1 AUTHOR
 
@@ -81,7 +81,7 @@ Steffen Winkler
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2014,
+Copyright (c) 2015,
 Steffen Winkler
 C<< <steffenw at cpan.org> >>.
 All rights reserved.
